#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2014 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using System.Drawing;

namespace HeuristicLab.Core.Networks {
  [Item("Message", "A message sent between ports.")]
  [StorableClass]
  public class Message : Item, IMessage {
    public static new Image StaticItemImage {
      get { return HeuristicLab.Common.Resources.VSImageLibrary.Field; }
    }

    [Storable]
    protected MessageValueCollection values;
    public MessageValueCollection Values {
      get { return values; }
    }
    public IItem this[string valueName] {
      get { return Values[valueName].Value; }
      set { Values[valueName].Value = value; }
    }

    [StorableConstructor]
    protected Message(bool deserializing) : base(deserializing) { }
    protected Message(Message original, Cloner cloner)
      : base(original, cloner) {
      values = cloner.Clone(original.values);
    }
    public Message() {
      values = new MessageValueCollection();
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new Message(this, cloner);
    }
  }
}
